Crate rialo_oracle_processor_interface

Crate rialo_oracle_processor_interface 

The Oracle Processor program interface.

Oracle Processor Interface

This crate is meant to be used as both entrypoint definition and utility along with the Oracle Processor program.

It contains a list of instructions that can be sent to the builtin program, along with some given Rust methods to easily generate them.

Modules

errors
event
Events emitted by the Oracle Processor program.
instruction
Instructions for the Oracle Processor program.
state

Constants

ID
The const program ID.

Functions

check_id
Returns true if given pubkey is the program ID.
id
Returns the program ID.