OracleReport

Struct OracleReport 

pub struct OracleReport {
    pub oracle_id: OracleId,
    pub round: u64,
    pub updates: Vec<OracleUpdate>,
}
Represents an oracle’s definition and configuration

Fields

oracle_id: OracleIdround: u64updates: Vec<OracleUpdate>

Implementations

Source

impl OracleReport

pub fn into_updates(self) -> Vec<OracleUpdate>

Converts the OracleReport into a Vec<OracleUpdate>

This function is used to extract the updates from the OracleReport

Returns

A vector of OracleUpdate instances

pub fn outputs_with_validators( &self, ) -> impl Iterator<Item = (Pubkey, OracleOutput)> + '_

Returns an iterator of tuples containing the validator Pubkey and OracleOutput

pub fn outputs(&self) -> impl Iterator<Item = OracleOutput> + '_

Returns an iterator over containing all the OracleOutput

Returns

Returns an iterator over all the OracleOutputs.

pub fn validators(&self) -> impl Iterator<Item = Pubkey> + '_

Returns an iterator over the validators

Returns

An iterator over the validators’ Pubkeys