pub struct OracleUpdate { /* private fields */ }Expand description
Oracle update structure
Implementations
Sourceimpl OracleUpdate
impl OracleUpdate
pub fn new(data: Vec<u8>, validator: AuthorityKeyBytes) -> Self
Sourcepub fn data(&self) -> &[u8] ⓘ
pub fn data(&self) -> &[u8] ⓘ
Returns the Oracle data as a Base64 encoded string
Returns
The output that resulted from the Oracle Duty being performed, serialized as bytes with Borsh
Sourcepub fn validator(&self) -> AuthorityKeyBytes
pub fn validator(&self) -> AuthorityKeyBytes
The 96-byte BLS12-381 authority public key of the validator.
Sourcepub fn try_data_as_output(&self) -> Result<OracleOutput, OracleProcessorError>
pub fn try_data_as_output(&self) -> Result<OracleOutput, OracleProcessorError>
Returns the data as OracleOutput
Returns
The output that resulted from the Oracle Duty being performed, deserialized as OracleOutput
Sourcepub fn success_payload(&self) -> Option<OracleData>
pub fn success_payload(&self) -> Option<OracleData>
Returns the OracleData payload returned by the oracle if the request was a success.
Otherwise, returns None.
Returns
An Option containing the OracleData payload if the oracle output was a success, or None otherwise.
pub fn get_oracle_response_timestamp(&self) -> Option<String>