pub enum OracleProcessorInstruction {
Report {
oracle_id: OracleId,
updates: Vec<OracleUpdate>,
},
}Expand description
Instructions supported by the Oracle Processor program. Made to report oracle updates from validators.
Variants
Report
Report oracle updates from validators
Fields

updates: Vec<OracleUpdate>Updates from each validator
Implementations
Sourceimpl OracleProcessorInstruction
impl OracleProcessorInstruction
Sourcepub fn report(
payer: Pubkey,
oracle_id: OracleId,
updates: Vec<OracleUpdate>,
) -> Instruction
pub fn report( payer: Pubkey, oracle_id: OracleId, updates: Vec<OracleUpdate>, ) -> Instruction
Creates an instruction for oracle reporting.
This function creates an instruction that will report an oracle update and emit an event that subscribers can listen to.
Arguments
payer- The public key of the payeroracle_id- The ID of the oracleupdates- A vector of oracle updates
Returns
An instruction that stores oracle data in a PDA and emits an event. Subscribers can listen to the instance-specific topic to receive notifications when oracle reports are stored.
Accounts
[0]- Payer account (signer, writable)[1]- Report PDA account (writable)[2]- Event PDA account (writable)[3]- System program (readonly)