pub enum OracleProcessorInstruction {
Report {
oracle_id: OracleId,
updates: Vec<OracleUpdate>,
},
}Expand description
Instructions supported by the Oracle Processor program. Made to report oracle updates from validators.
Variants
Report
Report oracle updates from validators
Fields

updates: Vec<OracleUpdate>Updates from each validator
Implementations
Sourceimpl OracleProcessorInstruction
impl OracleProcessorInstruction
Sourcepub fn report(
payer: Pubkey,
aggregators: Vec<(String, Pubkey)>,
oracle_id: OracleId,
updates: Vec<OracleUpdate>,
) -> Vec<Instruction>
pub fn report( payer: Pubkey, aggregators: Vec<(String, Pubkey)>, oracle_id: OracleId, updates: Vec<OracleUpdate>, ) -> Vec<Instruction>
Creates instructions for oracle reporting.
This function creates an instruction that will report an oracle update.
Arguments
payer- The public key of the payeraggregators- A vector of tuples containing the topic and the aggregator program ID. Note: Ifupdatesis empty, no aggregation instructions will be created regardless of the aggregators provided, as there is no data to aggregate.oracle_id- The ID of the oracleupdates- A vector of oracle updates. If empty, no aggregation instructions will be generated.
Returns
A vector of instructions to include in the transaction:
- First instruction: Report instruction that stores oracle data in a PDA
- Subsequent instructions: One aggregation instruction for each aggregator
(only if
updatesis not empty)
Behavior
When updates is empty, the function will:
- Still create the report instruction (to maintain consistency)
- Skip all aggregation instructions, effectively ignoring the
aggregatorsparameter - Return a vector containing only the report instruction
This behavior prevents triggering aggregators when there is no oracle data to process.